@@ -1,14 +1,27 @@
 use strict;
 use warnings;
 package Data::Hive::PathPacker::Strict;
-{
-  $Data::Hive::PathPacker::Strict::VERSION = '1.011';
-}
-use base 'Data::Hive::PathPacker';
 # ABSTRACT: a simple, strict path packer
+$Data::Hive::PathPacker::Strict::VERSION = '1.012';
+use parent 'Data::Hive::PathPacker';
 
 use Carp ();
 
+#pod =head1 DESCRIPTION
+#pod
+#pod The Strict path packer is the simplest useful implementation of
+#pod L<Data::Hive::PathPacker>.  It joins path parts together with a fixed string
+#pod and splits them apart on the same string.  If the fixed string occurs any path
+#pod part, an exception is thrown.
+#pod
+#pod =method new
+#pod
+#pod   my $packer = Data::Hive::PathPacker::Strict->new( \%arg );
+#pod
+#pod The only valid argument is C<separator>, which is the string used to join path
+#pod parts.  It defaults to a single period.
+#pod
+#pod =cut
 
 sub new {
   my ($class, $arg) = @_;
@@ -53,7 +66,7 @@ Data::Hive::PathPacker::Strict - a simple, strict path packer
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 DESCRIPTION
 
